class Lending:
    # service
    aave_v2 = "aave-v2"
    aave_v3 = "aave-v3"
    radiant_v2 = "radiant-v2"
    compound = "compound"
    flux = "flux-finance"
    iron_bank = "iron-bank"
    trava = "trava-finance"
    valas = "valas-finance"
    geist = "geist-finance"
    cream = "cream-lending"
    venus = "venus"
    liqee = "liqee"
    strike = "strike"
    uwu = "uwu-lend"
    onyx = "onyx-protocol"
    granary = "granary-finance"
    wepiggy = "wepiggy"
    morpho_compound = 'morpho-compound'
    morpho_aave_v2 = 'morpho-aave'
    morpho_aave_v3 = 'morpho-aavev3'
    spark = 'spark'
    ape_swap = "apeswap-lending"
    silo = 'silo-finance'
    compound_v3 = 'compound-v3'
    justlend = "justlend"
    all = [strike, aave_v2, aave_v3, radiant_v2, compound, flux, onyx, granary,
           iron_bank, trava, valas, geist, cream, venus, liqee, strike, uwu, wepiggy,
           morpho_compound, morpho_aave_v2, morpho_aave_v3, spark, ape_swap, silo, compound_v3,
           justlend
           ]
