class MongoDBCollections:
    wallets = 'wallets'
    projects = 'projects'
    smart_contracts = 'smart_contracts'
    relationships = 'relationships'
    call_smart_contracts = 'call_smart_contracts'
    abi = 'abi'
    configs = 'configs'
    multichain_wallets = 'multichain_wallets'
    multichain_wallets_credit_scores = 'multichain_wallets_credit_scores'

    is_part_ofs = 'is_part_ofs'



